@@ -1,8 +1,10 @@
 package Moose::Autobox::Code;
+# ABSTRACT: the Code role
 use Moose::Role 'with';
 use Moose::Autobox;
+use namespace::autoclean;
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 with 'Moose::Autobox::Ref';
 
@@ -17,7 +19,7 @@ sub rcurry {
 }
 
 sub compose {
-	my ($f, $f2, @rest) = @_;
+    my ($f, $f2, @rest) = @_;
     return $f if !$f2;
     return (sub { $f2->($f->(@_)) })->compose(@rest);
 }
@@ -26,10 +28,10 @@ sub disjoin {
     my ($f, $f2) = @_;
     return sub { $f->(@_) || $f2->(@_) }
 }
-        
+
 sub conjoin {
-	my ($f, $f2) = @_;
-	return sub { $f->(@_) && $f2->(@_) }    
+    my ($f, $f2) = @_;
+    return sub { $f->(@_) && $f2->(@_) }
 }
 
 # fixed point combinators
@@ -50,20 +52,26 @@ __END__
 
 =pod
 
-=head1 NAME 
+=encoding UTF-8
+
+=head1 NAME
 
 Moose::Autobox::Code - the Code role
 
-=head1 SYNOPOSIS
+=head1 VERSION
+
+version 0.16
+
+=head1 SYNOPSIS
 
   use Moose::Autobox;
-  
+
   my $adder = sub { $_[0] + $_[1] };
   my $add_2 = $adder->curry(2);
-  
+
   $add_2->(2); # returns 4
-  
-  # create a recursive subroutine 
+
+  # create a recursive subroutine
   # using the Y combinator
   *factorial = sub {
       my $f = shift;
@@ -73,36 +81,37 @@ Moose::Autobox::Code - the Code role
           return $n * $f->($n - 1);
       }
   }->y;
-  
+
   factorial(10) # returns 3628800
-  
 
 =head1 DESCRIPTION
 
-This is a role to describe operations on the Code type. 
+This is a role to describe operations on the Code type.
 
 =head1 METHODS
 
 =over 4
 
-=item B<curry (@values)>
+=item C<curry (@values)>
 
-=item B<rcurry (@values)>
+=item C<rcurry (@values)>
 
-=item B<conjoin (\&sub)>
+=item C<conjoin (\&sub)>
 
-=item B<disjoin (\&sub)>
+=item C<disjoin (\&sub)>
 
-=item B<compose (@subs)>
+=item C<compose (@subs)>
 
-This will take a list of C<@subs> and compose them all into a single 
-subroutine where the output of one sub will be the input of another. 
+This will take a list of C<@subs> and compose them all into a single
+subroutine where the output of one sub will be the input of another.
 
-=item B<y>
+=item C<y>
+
+=for :stopwords combinator
 
 This implements the Y combinator.
 
-=item B<u>
+=item C<u>
 
 This implements the U combinator.
 
@@ -110,7 +119,7 @@ This implements the U combinator.
 
 =over 4
 
-=item B<meta>
+=item C<meta>
 
 =back
 
@@ -124,23 +133,26 @@ This implements the U combinator.
 
 =back
 
-=head1 BUGS
+=head1 SUPPORT
 
-All complex software has bugs lurking in it, and this module is no 
-exception. If you find a bug please either email me, or add the bug
-to cpan-RT.
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Moose-Autobox>
+(or L<bug-Moose-Autobox@rt.cpan.org|mailto:bug-Moose-Autobox@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://lists.perl.org/list/moose.html>.
+
+There is also an irc channel available for users of this distribution, at
+L<C<#moose> on C<irc.perl.org>|irc://irc.perl.org/#moose>.
 
 =head1 AUTHOR
 
-Stevan Little E<lt>stevan@iinteractive.comE<gt>
+Stevan Little <stevan.little@iinteractive.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006-2008 by Infinity Interactive, Inc.
+This software is copyright (c) 2006 by Infinity Interactive, Inc.
 
-L<http://www.iinteractive.com>
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
